summaryrefslogtreecommitdiff
path: root/framework
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2018-07-31 10:21:14 +0200
committerJulien Nabet <serval2412@yahoo.fr>2018-07-31 11:30:58 +0200
commit1de9dc5ff788105a6de7988e5ed5cbad84e807b7 (patch)
treea9dd32f26922b9acb12a77e7098c7ff773aa3a93 /framework
parenta43b79f6f9d16d52cdd30b990169160573e5de17 (diff)
Fix typos
Change-Id: If8897807f065a342ef0e7f923199660079a70d22 Reviewed-on: https://gerrit.libreoffice.org/58123 Reviewed-by: Julien Nabet <serval2412@yahoo.fr> Tested-by: Jenkins
Diffstat (limited to 'framework')
-rw-r--r--framework/inc/services/desktop.hxx4
-rw-r--r--framework/source/jobs/job.cxx8
-rw-r--r--framework/source/services/desktop.cxx8
-rw-r--r--framework/source/services/frame.cxx4
4 files changed, 12 insertions, 12 deletions
diff --git a/framework/inc/services/desktop.hxx b/framework/inc/services/desktop.hxx
index 09a9318a2906..04438ecc14d9 100644
--- a/framework/inc/services/desktop.hxx
+++ b/framework/inc/services/desktop.hxx
@@ -153,7 +153,7 @@ class Desktop : private cppu::BaseMutex,
@seealso XTerminateListener
@seealso XTerminateListener2
- @return true if all open frames could be closed and no listener throwed
+ @return true if all open frames could be closed and no listener threw
a veto exception; false otherwise.
@onerror False will be returned.
@@ -318,7 +318,7 @@ class Desktop : private cppu::BaseMutex,
* about cancel this termination request.
*
* @param [out] bVeto
- * will be true if at least one listener throwed a veto exception;
+ * will be true if at least one listener threw a veto exception;
* false otherwise.
*
* @see impl_sendCancelTerminationEvent()
diff --git a/framework/source/jobs/job.cxx b/framework/source/jobs/job.cxx
index 047bb7170004..3082526bfb71 100644
--- a/framework/source/jobs/job.cxx
+++ b/framework/source/jobs/job.cxx
@@ -229,9 +229,9 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
if (m_eRunState == E_RUNNING)
m_eRunState = E_STOPPED_OR_FINISHED;
- // If we got a close request from our frame or model ...
+ // If we got a close request from our frame or model...
// but we disagreed wit that by throwing a veto exception...
- // and got the ownership ...
+ // and got the ownership...
// we have to close the resource frame or model now -
// and to disable ourself!
if (m_bPendingCloseFrame)
@@ -686,8 +686,8 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& )
@short inform us about office termination
@descr Instead of the method queryTermination(), here is no chance to disagree with that.
We have to accept it and cancel all current processes inside.
- It can occur only, if job was not already started if queryTermination() was called here ..
- Then we had not throwed a veto exception. But now we must agree with this situation and break
+ It can occur only, if job was not already started if queryTermination() was called here.
+ Then we had not thrown a veto exception. But now we must agree with this situation and break
all our internal processes. It's not a good idea to mark this instance as non startable any longer
inside queryTermination() if no job was running too. Because that would disable this job and may
the office does not really shutdown, because another listener has thrown the suitable exception.
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index 17856a70a81b..111a3a8f0a7e 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -1748,15 +1748,15 @@ bool Desktop::impl_closeFrames(bool bAllowUI)
++nNonClosedFrames;
// Reactivate controller.
- // It can happen that XController.suspend() returned true ... but a registered close listener
- // throwed these veto exception. Then the controller has to be reactivated. Otherwise
+ // It can happen that XController.suspend() returned true... but a registered close listener
+ // threw these veto exception. Then the controller has to be reactivated. Otherwise
// these document doesn't work any more.
if ( bSuspended && xController.is())
xController->suspend(false);
}
- // If interface XClosable interface exists and was used ...
- // it's not allowed to use XComponent->dispose() also !
+ // If interface XClosable interface exists and was used...
+ // it's not allowed to use XComponent->dispose() also!
continue;
}
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 8bbecd5c434a..a7f60298aeb9 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -1635,7 +1635,7 @@ void SAL_CALL Frame::removeFrameActionListener( const css::uno::Reference< css::
@param bDeliverOwnership
If parameter is set to <FALSE/> the original caller will be the owner after thrown
veto exception and must try to close this frame at later time again. Otherwise the
- source of throwed exception is the right one. May it will be the frame himself.
+ source of thrown exception is the right one. May it will be the frame himself.
@throws CloseVetoException
if any internal things willn't be closed
@@ -3175,7 +3175,7 @@ void Frame::implts_checkSuicide()
m_bSelfClose = false;
aReadLock.clear();
/* } SAFE */
// force close and deliver ownership to source of possible throwed veto exception
// Attention: Because this method is not designed to throw such exception we must suppress
// it for outside code!
try
@@ -3175,7 +3175,7 @@ void Frame::implts_checkSuicide()
aReadLock.clear();
/* } SAFE */
- // force close and deliver ownership to source of possible throwed veto exception
+ // force close and deliver ownership to source of possible thrown veto exception
// Attention: Because this method is not designed to throw such exception we must suppress
// it for outside code!